<?php 
/**
 * @file
 * Administrative forms and callbacks.
 *
 */
drupal_load('module', 'eventbookings');  

/**
 * Implementation of hook_admin().
 */
function eventbookings_admin() {
  return drupal_get_form('eventbookings_admin_form');
}

/**
 * Build the administrative form for bookable Node Types
 * 
 * @param unknown_type $form_state
 * @return multitype:string The 
 */
function eventbookings_admin_form(&$form_state) {
  drupal_add_js(drupal_get_path('module', 'eventbookings') . '/js/admin.js');
  drupal_add_js(array( 'eventbookings' => 
    array(
      'date_field' => 'eventbookings-datefield',
      'clear_button' => 'eventbookings-bookings-clear',
      'checkbox_type' => ($multiple_bookings) ? 'checkbox' : 'radio',
      'eventbookings' => 'eventbookings-wrapper',
      'status' => 'eventbookings-status'
      )
  ), 'setting');
  
  // Select all the node types that have a date field
  // TODO : Is there a future proof api way to do this?  Can't figure it out looking at the date module
  $result = db_query( 
    'SELECT ' .
      'nt.name, nt.description, nt.type, cnfi.field_name ' .
    'FROM ' .
      '{content_node_field} cnf join ' .
      '{%s} cnfi on cnf.field_name=cnfi.field_name join ' .
      '{node_type} nt on nt.type=cnfi.type_name ' .
    'WHERE ' .
      'cnf.type="date" or cnf.type="datetime" or cnf.type="datestamp" ' .
    'ORDER BY nt.name, nt.description, nt.type', content_instance_tablename());
  
  // Build an array of data
  $types = array();
  while ($row = db_fetch_array($result)) {
    $node_name = $row['name'];
    $types[$row['type']]['name'] = $node_name;
    $types[$row['type']]['description'] =$row['description'];
    $types[$row['type']]['type'] =$row['type'];
    $types[$row['type']][EVENTBOOKINGS_DATE_FIELD_PREFIX . $row['type']][$row['field_name']] =$row['field_name'];
  }

  $form[EVENTBOOKINGS_ENABLED_TYPES . '_header']  = array(
    '#type' => 'markup',
    '#value' => '<h2>'. t('Per Content Type Settings:') . '</h2>',
  );
  
  if (count($types) > 0 ) {
    foreach ( $types as $type ) {
      // Allow the user to disable the node
      $type[EVENTBOOKINGS_DATE_FIELD_PREFIX . $type['type']][EVENTBOOKINGS_EVENT_DISABLED] = t('disable bookings');
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']] = array(
        '#type' => 'fieldset', 
        '#title' => $type['name'] . ':  ' . $type['description']
      );
      $fieldset_title = variable_get(EVENTBOOKINGS_FIELDSET_TITLE . $type['type'], t('Book available Resources'));
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_FIELDSET_TITLE . $type['type']] = array(
        '#type' => 'textfield',
        '#title' => t('Fieldset title'),
        '#default_value' => $fieldset_title
      );
      $description = variable_get(EVENTBOOKINGS_DESCRIPTION . $type['type'], '');
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_DESCRIPTION . $type['type']] = array(
        '#type' => 'textfield',
        '#title' => t('Fieldset description'),
        '#default_value' => $description
      );
      $is_collapsable = variable_get(EVENTBOOKINGS_COLLAPSABLE . $type['type'], TRUE);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_COLLAPSABLE . $type['type']] = array(
        '#type' => 'checkbox',
        '#title' => t('Collapsable fieldset'),
        '#default_value' => $is_collapsable,
      );
      $is_availability = variable_get(EVENTBOOKINGS_IS_AVAILABILITY . $type['type'], FALSE);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_IS_AVAILABILITY . $type['type']] = array(
        '#type' => 'checkbox',
        '#title' => t('This content type defines availability for a resource'),
        '#default_value' => $is_availability,
        '#attributes' => array( 'class' => 'availability', 'content_type' => $type['type'])
      );
      $multiple_bookings = variable_get(EVENTBOOKINGS_MULTIPLE_BOOKINGS_PREFIX . $type['type'], FALSE);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_MULTIPLE_BOOKINGS_PREFIX . $type['type']] = array(
        '#type' => 'checkbox',
        '#title' => t('Allow mutiple booking of resources'),
        '#default_value' => $multiple_bookings
      );
      $pending_conflict = variable_get(EVENTBOOKINGS_PENDING_AS_CONFLICT . $type['type'], TRUE);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_PENDING_AS_CONFLICT . $type['type']] = array(
        '#type' => 'checkbox',
        '#title' => t('Pending bookings appear as a conflict'),
        '#default_value' => $pending_conflict
      );
      $curr_status = variable_get(EVENTBOOKINGS_DEFAULT_STATUS . $type['type'], BOOKINGSAPI_STATUS_FINALIZED);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_DEFAULT_STATUS . $type['type']] = array(
        '#title' => t('Default Booking status'),
        '#type' => 'select',
        '#description' => t('Booking status does not apply to availabilities'),
        '#options' =>  bookingsapi_record_status(),
        '#default_value' => ($curr_status != '') ? $curr_status : BOOKINGSAPI_STATUS_FINALIZED,
        '#attributes' => array( 'class' => $type['type'] . '_status', 'disabled' => 'disabled')
      );
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_DATE_FIELD_PREFIX . $type['type']] = array(
        '#type' => 'radios', 
        '#title' => t('Select the date field for bookings'),
        '#options' => $type[EVENTBOOKINGS_DATE_FIELD_PREFIX . $type['type']],
        '#default_value' => variable_get(EVENTBOOKINGS_DATE_FIELD_PREFIX . $type['type'], '')
      );
      $bookings_weight = variable_get(EVENTBOOKINGS_WEIGHT_PREFIX . $type['type'], 40);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']][EVENTBOOKINGS_WEIGHT_PREFIX . $type['type']] = array(
        '#type' => 'textfield',
        '#title' => t('The weight of the bookings fieldset in the form'),
        '#default_value' => $bookings_weight
      );
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']]['all_day'] = array(
        '#type' => 'fieldset',
        '#title' => t('Booking times for an all day event'),
      );      
      
      $all_date_enabled = variable_get(EVENTBOOKINGS_AD_ENABLE . $type['type'], TRUE);
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']]['all_day'][EVENTBOOKINGS_AD_ENABLE . $type['type']] = array(
        '#type' => 'checkbox',
        '#title' => t('Enable all day support'),
        '#description' => t('If enabled, a date duration of 00:00 signifies an all day event'),
        '#default_value' => $all_date_enabled,
        '#attributes' => array( 'class' => 'all-day-event', 'content_type' => $type['type'])
      );
      $all_date_start = variable_get(EVENTBOOKINGS_AD_START . $type['type'], '1970-01-01 08:00:00');
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']]['all_day'][EVENTBOOKINGS_AD_START . $type['type']] = array(
        '#type' => 'date_select',
        '#title' => t('Start time'),
        '#default_value' => $all_date_start, 
        '#date_format' => 'H:i',
        '#attributes' => array( 'class' => $type['type'] . '-time-select')
      );
      $all_date_end = variable_get(EVENTBOOKINGS_AD_END . $type['type'], '1970-01-01 17:00:00');
      $form[EVENTBOOKINGS_ENABLED_TYPES][$type['type']]['all_day'][EVENTBOOKINGS_AD_END . $type['type']] = array(
        '#type' => 'date_select',
        '#title' => t('End time'),
        '#default_value' => $all_date_end, 
        '#date_format' => 'H:i',
        '#attributes' => array( 'class' => $type['type'] . '-time-select')
      );      
    }
  }
  else {
    $form[EVENTBOOKINGS_ENABLED_TYPES]['message'] = array(
      '#type' => 'markup', 
      '#value' => '<div class="messages warning">'. t('There are no date enabled content types') . '</div>'
      );
  }
  return system_settings_form($form);
}
